.custom-button,.custom-label{background-color:#282434;outline:none;padding:10px;color:#fff;border-radius:5px;border:none;font-size:12px;margin:4px;box-sizing:border-box;font-family:sans-serif}.custom-button:active,.custom-button:hover{background-color:#1e1b2a}.custom-button:active{-webkit-transform:translateY(4px);transform:translateY(4px)}.custom-textinput{background-color:#282434;padding:10px;color:#fff;border-radius:5px;border:none;font-size:12px;margin:4px;box-sizing:border-box;width:9.9%}.custom-textinput:focus{outline:2px solid #ff3030}.image-container{background-size:contain;position:relative;display:inline-block}.control-container{display:flex;flex-direction:row;height:50px;align-items:center}.slider{margin-left:10px;margin-bottom:5px}
/*# sourceMappingURL=main.885a9fab.chunk.css.map */